Stan Math Library: stan/math/prim/scal/meta/likely.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

likely.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_LIKELY_HPP
2 #define STAN_MATH_PRIM_SCAL_META_LIKELY_HPP
3
4 #ifdef __GNUC__
5 #define likely(x) __builtin_expect(!!(x), 1)
6 #define unlikely(x) __builtin_expect(!!(x), 0)
7 #else
8 #define likely(x) (x)
9 #define unlikely(x) (x)
10 #endif
11
12 #endif

[ Stan Home Page ] © 2011–2016, Stan Development Team.